Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
GDAL-VECTOR-SELECT(1)		      GDAL		   GDAL-VECTOR-SELECT(1)

NAME
     gdal-vector-select - Select a subset of fields from a vector dataset

     Added in version 3.11.

SYNOPSIS
	Usage: gdal vector select [OPTIONS] <INPUT> <OUTPUT> <FIELDS>

	Select a subset of fields from a vector dataset.

	Positional arguments:
	  -i, --input <INPUT>				       Input vector datasets [required] [not available in pipelines]
	  -o, --output <OUTPUT> 			       Output vector dataset [required] [not available in pipelines]
	  --fields <FIELDS>				       Fields to select (or exclude if --exclude) [may be repeated] [required]

	Common Options:
	  -h, --help					       Display help message and exit
	  --json-usage					       Display usage as JSON document and exit
	  --config <KEY>=<VALUE>			       Configuration option [may be repeated]
	  -q, --quiet					       Quiet mode (no progress bar or warning message) [not available in pipelines]

	Options:
	  -l, --layer, --input-layer <INPUT-LAYER>	       Input layer name(s) [may be repeated] [not available in pipelines]
	  -f, --of, --format, --output-format <OUTPUT-FORMAT>  Output format ("GDALG" allowed) [not available in pipelines]
	  --co, --creation-option <KEY>=<VALUE> 	       Creation option [may be repeated] [not available in pipelines]
	  --lco, --layer-creation-option <KEY>=<VALUE>	       Layer creation option [may be repeated] [not available in pipelines]
	  --overwrite					       Whether overwriting existing output dataset is allowed [not available in pipelines]
	  --update					       Whether to open existing dataset in update mode [not available in pipelines]
	  --overwrite-layer				       Whether overwriting existing output layer is allowed [not available in pipelines]
	  --append					       Whether appending to existing layer is allowed [not available in pipelines]
							       Mutually exclusive with --upsert
	  --output-layer <OUTPUT-LAYER> 		       Output layer name
	  --skip-errors 				       Skip errors when writing features [not available in pipelines]
	  --active-layer <ACTIVE-LAYER> 		       Set active layer (if not specified, all)
	  --exclude					       Exclude specified fields
							       Mutually exclusive with --ignore-missing-fields
	  --ignore-missing-fields			       Ignore missing fields
							       Mutually exclusive with --exclude

	Advanced Options:
	  --if, --input-format <INPUT-FORMAT>		       Input formats [may be repeated] [not available in pipelines]
	  --oo, --open-option <KEY>=<VALUE>		       Open options [may be repeated] [not available in pipelines]
	  --output-oo, --output-open-option <KEY>=<VALUE>      Output open options [may be repeated] [not available in pipelines]
	  --upsert					       Upsert features (implies 'append') [not available in pipelines]
							       Mutually exclusive with --append

DESCRIPTION
     gdal vector select can be used to select a subset of fields.

     select can also be used as a step of gdal vector pipeline.

GDALG OUTPUT (ON-THE-FLY / STREAMED DATASET)
     This program supports serializing the command line as a JSON file using the
     GDALG  output  format.   The  resulting file can then be opened as a vector
     dataset using the GDALG: GDAL Streamed  Algorithm	driver,  and  apply  the
     specified pipeline in a on-the-fly / streamed way.

PROGRAM-SPECIFIC OPTIONS
     --exclude
	    Modifies  the behavior of the algorithm such that all fields are se-
	    lected, except the ones mentioned by --fields.

     --fields <FIELDS>
	    Comma-separated list of fields from input layer to copy to	the  new
	    layer (or to exclude if --exclude is specified)

	    Field names with spaces, commas or double-quote should be surrounded
	    with  a starting and ending double-quote character, and double-quote
	    characters in a field name should be escaped with backslash.

	    Depending on the shell used, this might require further quoting. For
	    example, to select regular_field, a_field_with space, and comma  and
	    a field with " double quote with a Unix shell:

	       --fields "regular_field,\"a_field_with space, and comma\",\"a field with \\\" double quote\""

	    A  field  is  only selected once, even if mentioned several times in
	    the list.

	    Geometry fields can also be specified in the  list.  If  the  source
	    layer  has	no  explicit name for the geometry field, _ogr_geometry_
	    must be used to select the unique geometry field.

	    Specifying a non-existing source field name results in an error.

     --ignore-missing-fields
	    By default, if a field specified by --fields does not exist  in  the
	    input  layer(s),  an error is emitted and the processing is stopped.
	    When specifying --ignore-missing-fields, only a warning  is  emitted
	    and the non existing fields are just ignored.

STANDARD OPTIONS
     --active-layer <ACTIVE-LAYER>
	    Set the active layer. When it is specified, only the layer specified
	    by	its name will be subject to the processing. Other layers will be
	    not modified.  If this option is not specified, all layers	will  be
	    subject to the processing.

     --append
	    Whether  appending	features  to existing layer(s) is allowed.  This
	    also creates the output dataset if it does not exist yet.

     --co, --creation-option <NAME>=<VALUE>
	    Many formats have one or more optional dataset creation options that
	    can be used to control particulars about the file created.	For  in-
	    stance,  the  GeoPackage driver supports creation options to control
	    the version.

	    May be repeated.

	    The dataset creation options available vary by  format  driver,  and
	    some  simple  formats have no creation options at all. A list of op-
	    tions supported for a format can be listed with the  --formats  com-
	    mand line option but the documentation for the format is the defini-
	    tive  source  of information on driver creation options.  See Vector
	    drivers format specific documentation for legal creation options for
	    each format.

	    Note that dataset creation options are different from layer creation
	    options.

     --if, --input-format <format>
	    Format/driver name to be attempted to open the input file(s). It  is
	    generally  not  necessary  to specify it, but it can be used to skip
	    automatic driver detection, when it fails to select the  appropriate
	    driver.   This  option can be repeated several times to specify sev-
	    eral candidate drivers.  Note that it does not force  those  drivers
	    to	open  the dataset. In particular, some drivers have requirements
	    on file extensions.

	    May be repeated.

     --input-layer <INPUT-LAYER>
	    Specifies the name of one or more layers to process. By default, all
	    layers will be processed. To read and  write  all  layers  but  only
	    process a subset, use --active-layer.

     --lco, --layer-creation-option <NAME>=<VALUE>
	    Many  formats  have one or more optional layer creation options that
	    can be used to control particulars about the layer created. For  in-
	    stance,  the  GeoPackage  driver  supports layer creation options to
	    control the feature identifier or geometry column name, setting  the
	    identifier or description, etc.

	    May be repeated.

	    The layer creation options available vary by format driver, and some
	    simple  formats have no layer creation options at all. A list of op-
	    tions supported for a format can be listed with the  --formats  com-
	    mand line option but the documentation for the format is the defini-
	    tive  source  of information on driver creation options.  See Vector
	    drivers format specific documentation for legal creation options for
	    each format.

	    Note that layer creation options are different from dataset creation
	    options.

     --oo, --open-option <NAME>=<VALUE>
	    Dataset open option (format specific).

	    May be repeated.

     -f, --of, --format, --output-format <OUTPUT-FORMAT>
	    Which output vector format to use. Allowed values may  be  given  by
	    gdal --formats | grep vector | grep rw | sort

     --output-layer <NAME>
	    Specifies  the  name of the layer to which features will be written.
	    If not specified, output layer names will be the same as input layer
	    names.

     --output-open-option, --output-oo <NAME>=<VALUE>
	    Added in version 3.12.

	    Dataset open option for output dataset (format specific).

	    May be repeated.

     --overwrite
	    Allow program to overwrite existing target file or dataset.   Other-
	    wise,  by default, gdal errors out if the target file or dataset al-
	    ready exists.

     --overwrite-layer
	    Whether overwriting the existing output vector layer is allowed.

     --skip-errors
	    Added in version 3.12.

	    Whether failures to write feature(s) should be  ignored.  Note  that
	    this  option sets the size of the transaction unit to one feature at
	    a time, which may cause severe slowdown when  inserting  into  data-
	    bases.

     --update
	    Whether to open an existing output dataset in update mode.

     --upsert
	    Added in version 3.12.

	    Variant of --append where the OGRLayer::UpsertFeature() operation is
	    used  to  insert  or  update  features  instead  of  appending  with
	    OGRLayer::CreateFeature().

	    This is currently  implemented  only  in  a  few  drivers:	GPKG  --
	    GeoPackage vector, Elasticsearch: Geographically Encoded Objects for
	    Elasticsearch  and	MongoDBv3  (drivers that implement upsert expose
	    the GDAL_DCAP_UPSERT capability).

	    The upsert operation uses the FID of the input feature, when  it  is
	    set (and the FID column name is not the empty string), as the key to
	    update existing features. It is crucial to make sure that the FID in
	    the source and target layers are consistent.

	    For  the  GPKG  driver, it is also possible to upsert features whose
	    FID is unset or non-significant (the --unset-fid option of gdal vec-
	    tor edit can be used to ignore the FID  from  the  source  feature),
	    when there is a UNIQUE column that is not the integer primary key.

RETURN STATUS CODE
     The  program returns status code 0 in case of success, and non-zero in case
     of error (non-blocking errors emitted as warnings are considered as a  suc-
     cessful execution).

EXAMPLES
   Example 1: Select the EAS_ID field and the geometry field from a Shapefile
	$ gdal vector select in.shp out.gpkg "EAS_ID,_ogr_geometry_" --overwrite

   Example 2: Remove sensitive fields from a layer
	$ gdal vector select in.shp out.gpkg --exclude "name,surname,address" --overwrite

AUTHOR
     Even Rouault <even.rouault@spatialys.com>

COPYRIGHT
     1998-2026

				  Jun 05, 2026		   GDAL-VECTOR-SELECT(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=gdal-vector-select&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help